@@ -17,6 +17,7 @@
 from __future__ import print_function
 
 import argparse
+import collections
 import copy
 import os
 import warnings
@@ -65,7 +66,7 @@ from cinderclient.v2 import availability_zones
            default=None,
            help='Filters results by a migration status. Default=None. '
                 'Admin only.')
-@utils.arg('--image_metadata',
+@utils.arg('--metadata',
            type=str,
            nargs='*',
            metavar='<key=value>',
@@ -125,9 +126,8 @@ def do_list(cs, args):
         'status': args.status,
         'bootable': args.bootable,
         'migration_status': args.migration_status,
-        'glance_metadata': shell_utils.extract_metadata(args,
-                                                        type='image_metadata')
-        if args.image_metadata else None,
+        'metadata': (shell_utils.extract_metadata(args) if args.metadata
+                     else None),
     }
 
     # If unavailable/non-existent fields are specified, these fields will
@@ -155,7 +155,11 @@ def do_list(cs, args):
         setattr(vol, 'attached_to', ','.join(map(str, servers)))
 
     if field_titles:
-        key_list = ['ID'] + field_titles
+        # Remove duplicate fields
+        key_list = ['ID']
+        unique_titles = [k for k in collections.OrderedDict.fromkeys(
+            [x.title().strip() for x in field_titles]) if k != 'Id']
+        key_list.extend(unique_titles)
     else:
         key_list = ['ID', 'Status', 'Name', 'Size', 'Volume Type',
                     'Bootable', 'Attached to']
@@ -341,47 +345,6 @@ def do_create(cs, args):
     utils.print_dict(info)
 
 
-@utils.arg('volume',
-           metavar='<volume>',
-           help='Name or ID of volume to snapshot.')
-@utils.arg('--force',
-           metavar='<True|False>',
-           const=True,
-           nargs='?',
-           default=False,
-           help='Enables or disables upload of '
-           'a volume that is attached to an instance. '
-           'Default=False. '
-           'This option may not be supported by your cloud.')
-@utils.arg('--container-format',
-           metavar='<container-format>',
-           default='bare',
-           help='Container format type. '
-                'Default is bare.')
-@utils.arg('--container_format',
-           help=argparse.SUPPRESS)
-@utils.arg('--disk-format',
-           metavar='<disk-format>',
-           default='raw',
-           help='Disk format type. '
-                'Default is raw.')
-@utils.arg('--disk_format',
-           help=argparse.SUPPRESS)
-@utils.arg('image_name',
-           metavar='<image-name>',
-           help='The new image name.')
-@utils.arg('--image_name',
-           help=argparse.SUPPRESS)
-def do_upload_to_image(cs, args):
-    """Uploads volume to Image Service as an image."""
-    volume = utils.find_volume(cs, args.volume)
-    shell_utils.print_volume_image(
-        volume.upload_to_image(args.force,
-                               args.image_name,
-                               args.container_format,
-                               args.disk_format))
-
-
 @utils.arg('--cascade',
            action='store_true',
            default=False,
@@ -962,13 +925,9 @@ def do_endpoints(cs, args):
 
 def do_credentials(cs, args):
     """Shows user credentials returned from auth."""
-    catalog = cs.client.service_catalog.catalog
-
-    # formatters defines field to be converted from unicode to string
-    utils.print_dict(catalog['user'], "User Credentials",
-                     formatters=['domain', 'roles'])
-    utils.print_dict(catalog['token'], "Token",
-                     formatters=['audit_ids', 'tenant'])
+    warnings.warn(
+        "``cinder credentials`` is deprecated, use ``openstack token issue`` "
+        "indead.")
 
 
 @utils.arg('tenant',
@@ -1685,14 +1644,19 @@ def do_encryption_type_show(cs, args):
            default=None,
            help='The encryption algorithm or mode. '
                 'For example, aes-xts-plain64. Default=None.')
-@utils.arg('--key_size',
+@utils.arg('--key-size',
            metavar='<key_size>',
            type=int,
            required=False,
            default=None,
            help='Size of encryption key, in bits. '
                 'For example, 128 or 256. Default=None.')
-@utils.arg('--control_location',
+@utils.arg('--key_size',
+           type=int,
+           required=False,
+           default=None,
+           help=argparse.SUPPRESS)
+@utils.arg('--control-location',
            metavar='<control_location>',
            choices=['front-end', 'back-end'],
            type=str,
@@ -1701,6 +1665,11 @@ def do_encryption_type_show(cs, args):
            help='Notional service where encryption is performed. '
                 'Valid values are "front-end" or "back-end." '
                 'For example, front-end=Nova. Default is "front-end."')
+@utils.arg('--control_location',
+           type=str,
+           required=False,
+           default='front-end',
+           help=argparse.SUPPRESS)
 def do_encryption_type_create(cs, args):
     """Creates encryption type for a volume type. Admin only."""
     volume_type = shell_utils.find_volume_type(cs, args.volume_type)
@@ -1725,8 +1694,7 @@ def do_encryption_type_create(cs, args):
            type=str,
            required=False,
            default=argparse.SUPPRESS,
-           help="Class providing encryption support (e.g. LuksEncryptor) "
-           "(Optional)")
+           help="Class providing encryption support (e.g. LuksEncryptor)")
 @utils.arg('--cipher',
            metavar='<cipher>',
            type=str,
@@ -1735,8 +1703,7 @@ def do_encryption_type_create(cs, args):
            default=argparse.SUPPRESS,
            const=None,
            help="Encryption algorithm/mode to use (e.g., aes-xts-plain64). "
-           "Provide parameter without value to set to provider default. "
-           "(Optional)")
+           "Provide parameter without value to set to provider default.")
 @utils.arg('--key-size',
            dest='key_size',
            metavar='<key-size>',
@@ -1746,8 +1713,7 @@ def do_encryption_type_create(cs, args):
            default=argparse.SUPPRESS,
            const=None,
            help="Size of the encryption key, in bits (e.g., 128, 256). "
-           "Provide parameter without value to set to provider default. "
-           "(Optional)")
+           "Provide parameter without value to set to provider default. ")
 @utils.arg('--control-location',
            dest='control_location',
            metavar='<control-location>',
@@ -1756,7 +1722,7 @@ def do_encryption_type_create(cs, args):
            required=False,
            default=argparse.SUPPRESS,
            help="Notional service where encryption is performed (e.g., "
-           "front-end=Nova). Values: 'front-end', 'back-end' (Optional)")
+           "front-end=Nova). Values: 'front-end', 'back-end'")
 def do_encryption_type_update(cs, args):
     """Update encryption type information for a volume type (Admin Only)."""
     volume_type = shell_utils.find_volume_type(cs, args.volume_type)
@@ -2125,19 +2091,6 @@ def do_consisgroup_show(cs, args):
     utils.print_dict(info)
 
 
-@utils.arg('group',
-           metavar='<group>',
-           help='Name or ID of a group.')
-def do_group_show(cs, args):
-    """Shows details of a group."""
-    info = dict()
-    group = shell_utils.find_group(cs, args.group)
-    info.update(group._info)
-
-    info.pop('links', None)
-    utils.print_dict(info)
-
-
 @utils.arg('volumetypes',
            metavar='<volume-types>',
            help='Volume types.')
